==> roms_tools-2.0.0.tar.gz: roms_tools-2.0.0/docs/datasets.md <==
# Required Datasets

To use `ROMS-Tools`, the user is required to download the following datasets:


| **Dataset** | **Supported Versions** | **Required Fields** | **Field Description**                                                      | **Available at**                                                                 | **Required For**    |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| TPXO        | TPXO9v2 (1/6 degree)   | `lat_r`             | Latitude at rho points (degrees north)                                     | [OSU TPXO Tide Models](https://www.tpxo.net/global)                             | Tidal Forcing       |
|             |                        | `lon_r`             | Longitude at rho points (degrees east)                                     |                                                                                  |                     |
|             |                        | `h_Re`              | Tidal elevation, real part (m)                                              |                                                                                  |                     |
|             |                        | `h_Im`              | Tidal elevation, imaginary part (m)                                         |                                                                                  |                     |
|             |                        | `sal_Re`            | SAL elevation, real part (m)                                               |                                                                                  |                     |
|             |                        | `sal_Im`            | SAL elevation, imaginary part (m)                                          |                                                                                  |                     |
|             |                        | `u_Re`              | Tidal transport WE, real part (m²/s)                                       |                                                                                  |                     |
|             |                        | `u_Im`              | Tidal transport WE, imaginary part (m²/s)                                  |                                                                                  |                     |
|             |                        | `v_Re`              | Tidal transport SN, real part (m²/s)                                       |                                                                                  |                     |
|             |                        | `v_Im`              | Tidal transport SN, imaginary part (m²/s)                                  |                                                                                  |                     |
|             |                        | `depth`             | Bathymetry at rho-points (m) — used for land masking                       |                                                                                  |                     |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| ERA5        | -                      | `time`              | Time                                                                      | [Climate Data Store](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels) | Surface Forcing     |
|             |                        | `latitude`          | Latitude (degrees north)                                                  |                                                                                  |                     |
|             |                        | `longitude`         | Longitude (degrees east)                                                  |                                                                                  |                     |
|             |                        | `u10`               | 10m U wind component (m/s)                                                 |                                                                                  |                     |
|             |                        | `v10`               | 10m V wind component (m/s)                                                 |                                                                                  |                     |
|             |                        | `ssr`               | Surface net short-wave (solar) radiation (W/m²)                            |                                                                                  |                     |
|             |                        | `strd`              | Surface long-wave (thermal) radiation downwards (W/m²)                     |                                                                                  |                     |
|             |                        | `t2m`               | 2m temperature (K)                                                        |                                                                                  |                     |
|             |                        | `d2m`               | 2m dewpoint temperature (K)                                               |                                                                                  |                     |
|             |                        | `tp`                | Total precipitation (m) (converted to mm for use in model)                 |                                                                                  |                     |
|             |                        | `sst`               | Sea surface temperature (K) — used for land masking                        |                                                                                  |                     |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| GLORYS      | -                      | `time`              | Time                                                                      | [Mercator Ocean](https://www.mercator-ocean.eu/en/ocean-science/glorys/) | Initial Conditions, Boundary Forcing     |
|             |                        | `latitude`          | Latitude (degrees north)                                                  |                                                                                  |                     |
|             |                        | `longitude`         | Longitude (degrees east)                                                  |                                                                                  |                     |
|             |                        | `depth`         | Depth (m)                                                  |                                                                                  |                     |
|             |                        | `zos`               | Sea surface height (m)                                                    |                                                                                  |                     |
|             |                        | `thetao`            | Temperature (degrees C)                                                   |                                                                                  |                     |
|             |                        | `so`                | Salinity (psu)                                                            |                                                                                  |                     |
|             |                        | `uo`                | Eastward velocity (m/s)                                                   |                                                                                  |                     |
|             |                        | `vo`                | Northward velocity (m/s)                                                  |                                                                                  |                     |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| Dai and Trenberth (coastal station volume, monthly series)      | 2019                      | `station`              | Station index                                                                      | [NCAR Research Data Archive](https://rda.ucar.edu/datasets/d551000/dataaccess/#) | River Forcing     |
|   |                       | `time`              | Time                                                                      | |      |
|  | -                      | `lat_mou`              | River mouth latitude                                                  |  |      |
|  | -                      | `lon_mou`              | River mouth longitude                                                  |  |      |
|  | -                      | `FLOW`              | Monthly mean volume at station                                                  |  |      |
|  | -                      | `ratio_m2s`              | Ratio of volume between river mouth and station                                                  |  |      |
|  | -                      | `riv_name`              | River name                                                  |  |      |
|  | -                      | `vol_stn` (optional)             | Annual volume at station                                                  |  |      |

==> roms_tools-2.2.1.tar.gz: roms_tools-2.2.1/docs/datasets.md <==
# Datasets

To use `ROMS-Tools`, the user is required to download the following datasets:


| **Dataset** | **Supported Versions** | **Required Fields** | **Field Description**                                                      | **Available at**                                                                 | **Required For**    |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| SRTM15        | V2.6   | `lat`             | Latitude (degrees north)                                     | [USCD SRTM15+ Product](https://topex.ucsd.edu/WWW_html/srtm15_plus.html)                             | Grid (Topography)       |
|         |    | `lon`             | Longitude (degrees east)                                     |                              |        |
|         |    | `z`             | Topography                                     |                              |        |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| TPXO        | TPXO9v2 (1/6 degree)   | `lat_r`             | Latitude at rho points (degrees north)                                     | [OSU TPXO Tide Models](https://www.tpxo.net/global)                             | Tidal Forcing       |
|             |                        | `lon_r`             | Longitude at rho points (degrees east)                                     |                                                                                  |                     |
|             |                        | `h_Re`              | Tidal elevation, real part (m)                                              |                                                                                  |                     |
|             |                        | `h_Im`              | Tidal elevation, imaginary part (m)                                         |                                                                                  |                     |
|             |                        | `sal_Re`            | SAL elevation, real part (m)                                               |                                                                                  |                     |
|             |                        | `sal_Im`            | SAL elevation, imaginary part (m)                                          |                                                                                  |                     |
|             |                        | `u_Re`              | Tidal transport WE, real part (m²/s)                                       |                                                                                  |                     |
|             |                        | `u_Im`              | Tidal transport WE, imaginary part (m²/s)                                  |                                                                                  |                     |
|             |                        | `v_Re`              | Tidal transport SN, real part (m²/s)                                       |                                                                                  |                     |
|             |                        | `v_Im`              | Tidal transport SN, imaginary part (m²/s)                                  |                                                                                  |                     |
|             |                        | `depth`             | Bathymetry at rho-points (m) — used for land masking                       |                                                                                  |                     |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| ERA5        | -                      | `time`              | Time                                                                      | [Climate Data Store](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels) | Surface Forcing     |
|             |                        | `latitude`          | Latitude (degrees north)                                                  |                                                                                  |                     |
|             |                        | `longitude`         | Longitude (degrees east)                                                  |                                                                                  |                     |
|             |                        | `u10`               | 10m U wind component (m/s)                                                 |                                                                                  |                     |
|             |                        | `v10`               | 10m V wind component (m/s)                                                 |                                                                                  |                     |
|             |                        | `ssr`               | Surface net short-wave (solar) radiation (W/m²)                            |                                                                                  |                     |
|             |                        | `strd`              | Surface long-wave (thermal) radiation downwards (W/m²)                     |                                                                                  |                     |
|             |                        | `t2m`               | 2m temperature (K)                                                        |                                                                                  |                     |
|             |                        | `d2m`               | 2m dewpoint temperature (K)                                               |                                                                                  |                     |
|             |                        | `tp`                | Total precipitation (m) (converted to mm for use in model)                 |                                                                                  |                     |
|             |                        | `sst`               | Sea surface temperature (K) — used for land masking                        |                                                                                  |                     |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| GLORYS      | -                      | `time`              | Time                                                                      | [Mercator Ocean](https://www.mercator-ocean.eu/en/ocean-science/glorys/) | Initial Conditions, Boundary Forcing     |
|             |                        | `latitude`          | Latitude (degrees north)                                                  |                                                                                  |                     |
|             |                        | `longitude`         | Longitude (degrees east)                                                  |                                                                                  |                     |
|             |                        | `depth`         | Depth (m)                                                  |                                                                                  |                     |
|             |                        | `zos`               | Sea surface height (m)                                                    |                                                                                  |                     |
|             |                        | `thetao`            | Temperature (degrees C)                                                   |                                                                                  |                     |
|             |                        | `so`                | Salinity (psu)                                                            |                                                                                  |                     |
|             |                        | `uo`                | Eastward velocity (m/s)                                                   |                                                                                  |                     |
|             |                        | `vo`                | Northward velocity (m/s)                                                  |                                                                                  |                     |
|-------------|------------------------|---------------------|---------------------------------------------------------------------------|----------------------------------------------------------------------------------|---------------------|
| Dai and Trenberth (coastal station volume, monthly series); **Note: downloaded internally**      | 2019                      | `station`              | Station index                                                                      | [NCAR Research Data Archive](https://rda.ucar.edu/datasets/d551000/dataaccess/#) | River Forcing     |
|   |                       | `time`              | Time                                                                      | |      |
|  | -                      | `lat_mou`              | River mouth latitude                                                  |  |      |
|  | -                      | `lon_mou`              | River mouth longitude                                                  |  |      |
|  | -                      | `FLOW`              | Monthly mean volume at station                                                  |  |      |
|  | -                      | `ratio_m2s`              | Ratio of volume between river mouth and station                                                  |  |      |
|  | -                      | `riv_name`              | River name                                                  |  |      |
|  | -                      | `vol_stn` (optional)             | Annual volume at station                                                  |  |      |
